#
# spec file for package cloud-init
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global configver 0.7

Name:           cloud-init
Version:        0.7.8
Release:        31.1
Summary:        Cloud node initialization tool
License:        GPL-3.0 and AGPL-3.0
Group:          System/Management
Url:            http://launchpad.net/cloud-init/
Source0:        %{name}-%{version}.tar.gz
Source1:        cloud.cfg.suse
Source2:        rsyslog-cloud-init.cfg
Patch0:         suseSysVInit.diff
# FIXME addopenSUSEBase.patch proposed for upstream merge
Patch1:         addopenSUSEBase.patch
# FIXME suseIntegratedHandler.patch proposed for upstream merge
Patch2:         suseIntegratedHandler.patch
Patch3:         setupSUSEsysVInit.diff
# FIXME openSUSEhostsTemplate.diff proposed for upstream merge
Patch5:         openSUSEhostsTemplate.diff
# FIXME dynamicInitCmd.patch proposed for upstream merge
Patch6:         dynamicInitCmd.diff
Patch9:         cloud-init-no-dmidecode-on-ppc64.patch
Patch10:        cloud-init-no-user-lock-if-already-locked.patch
Patch11:        dataSourceOpenNebula.patch
Patch12:        fix-default-systemd-unit-dir.patch
Patch14:        cloud-init-finalbeforelogin.patch
# python2 disables SIGPIPE, causing broken pipe errors in shell scripts (bsc#903449)
Patch20:        cloud-init-python2-sigpipe.patch
Patch21:        cloud-init-net-eni.patch
Patch22:        cloud-init-service.patch
Patch23:        cloud-init-fix-unicode-handling-binarydecode.patch
# From upstream patch
Patch24:        cloud-init-handle-no-carrier.patch
Patch25:        cloud-init-digital-ocean-datasource.patch
Patch26:        cloud-init-digital-ocean-datasource-enable-by-default.patch
Patch27:        cloud-init-sysconfig-netpathfix.patch
Patch28:        zypp_add_repos.diff
Patch29:        datasourceLocalDisk.patch
Patch30:        cloud-init-handle-not-implemented-query.patch
BuildRequires:  fdupes
BuildRequires:  filesystem
BuildRequires:  python-devel
BuildRequires:  python-setuptools
# pkg-config is needed to find correct systemd unit dir
BuildRequires:  pkg-config
# needed for /lib/udev
BuildRequires:  udev
%if 0%{?suse_version} > 1320
# Test requirements
BuildRequires:  python-Cheetah
BuildRequires:  python-Jinja2
BuildRequires:  python-PrettyTable
BuildRequires:  python-PyYAML
BuildRequires:  python-argparse
BuildRequires:  python-configobj
BuildRequires:  python-contextlib2
BuildRequires:  python-httpretty
BuildRequires:  python-jsonpatch
BuildRequires:  python-mock
BuildRequires:  python-oauthlib
BuildRequires:  python-requests
BuildRequires:  python-testtools
%endif
Requires:       bash
Requires:       cloud-init-config = %configver
Requires:       e2fsprogs
Requires:       file
Requires:       growpart
Requires:       net-tools
Requires:       openssh
Requires:       python-Jinja2
Requires:       python-PrettyTable
Requires:       python-PyYAML
Requires:       python-argparse
Requires:       python-boto >= 2.7
Requires:       python-cheetah
Requires:       python-configobj
Requires:       python-jsonpatch
Requires:       python-oauthlib
Requires:       python-pyserial
Requires:       python-requests
Requires:       python-setuptools
Requires:       python-six
Requires:       python-xml
Requires:       sudo
Requires:       util-linux
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%define         docdir %{_defaultdocdir}/%{name}
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%ifarch %ix86 x86_64
Requires:       pmtools
%endif
%else
%ifarch %ix86 x86_64
Requires:       dmidecode
%endif
%endif
%if 0%{?suse_version} && 0%{?suse_version} <= 1210
%define initsys sysvinit_suse
Patch40:        cloud-init-python26.patch
%else
%define initsys systemd
BuildRequires:  systemd
Requires:       systemd
%{?systemd_requires}
%if 0%{?suse_version} && 0%{?suse_version} == 1220
%define systemd_prefix /lib
%else
%define systemd_prefix /usr/lib
%endif
%endif
%if 0%{?suse_version} && 0%{?suse_version} >= 1315
Requires:       wicked-service
%else
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
Requires:       sysconfig
%else
Requires:       sysconfig-network
%endif
%endif

%description
Cloud-init is an init script that initializes a cloud node (VM)
according to the fetched configuration data from the admin node.

%package config-suse
Summary:        Configuration file for Cloud node initialization tool
Group:          System/Management
Provides:       cloud-init-config = %configver
Conflicts:      otherproviders(cloud-init-config)

%description config-suse
This package contains the product specific configuration file
for cloud-init.

%package doc
Summary:        Cloud node initialization tool - Documentation
Group:          System/Management
Recommends:     cloud-init = %{version}

%description doc
Cloud-init is an init script that initializes a cloud node (VM)
according to the fetched configuration data from the admin node.

Documentation and examples for cloud-init tools

%package test
Summary:        Cloud node initialization tool  - Testsuite
Group:          System/Management
Requires:       cloud-init = %{version}

%description test
Cloud-init is an init script that initializes a cloud node (VM)
according to the fetched configuration data from the admin node.

Unit tests for the cloud-init tools

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2
%patch3
%patch5
%patch6
%patch9
%patch10 -p1
%patch11
%patch12
%patch14
%patch20
%patch21
%patch22
%patch23
%patch24
%patch25 -p1
%patch26 -p1
%patch27
%patch28 -p0
%patch29 -p0
%patch30
%if 0%{?suse_version} && 0%{?suse_version} <= 1210
%patch40 -p1
%endif

%if 0%{?suse_version} <= 1130
# disable ecdsa for SLE 11 (not available)
echo "ssh_genkeytypes: ['rsa', 'dsa']" >> %{SOURCE1}
%endif

%build
python setup.py build

%if 0%{?suse_version} > 1320
%check
# these tests are currently failing due to suse patches
rm -v tests/unittests/test_distros/test_netconfig.py
rm -v tests/unittests/test_net.py
rm -v tests/unittests/test_datasource/test_opennebula.py
rm -v tests/unittests/test_datasource/test_cloudstack.py
python -m testtools.run
%endif

%install
python setup.py install --root=%{buildroot} --prefix=%{_prefix} --install-lib=%{python_sitelib} --init-system=%{initsys}
find %{buildroot} \( -name .gitignore -o -name .placeholder \) -delete
# from debian install script
for x in "%{buildroot}%{_bindir}/"*.py; do
   [ -f "${x}" ] && mv "${x}" "${x%.py}"
done
mkdir -p %{buildroot}%{_localstatedir}/lib/cloud
# move documentation
mkdir -p %{buildroot}%{_defaultdocdir}
mv %{buildroot}%{_datadir}/doc/%{name} %{buildroot}%{docdir}
cp -a %{SOURCE1} %{buildroot}/%{_sysconfdir}/cloud/cloud.cfg
# copy the LICENSE
cp LICENSE %{buildroot}%{docdir}
# Set the distribution indicator
%if 0%{?suse_version}
%if 0%{?suse_version} < 1130
#SLE 11, openSUSE 11.x is EOL
sed -i s/INSERT_SUSE_DISTRO/sles/ %{buildroot}/%{_sysconfdir}/cloud/cloud.cfg
%endif
%if 0%{?suse_version} > 1140
%if 0%{?suse_version} == 1315
# SLE 12
sed -i s/INSERT_SUSE_DISTRO/sles/ %{buildroot}/%{_sysconfdir}/cloud/cloud.cfg
%else
sed -i s/INSERT_SUSE_DISTRO/opensuse/ %{buildroot}/%{_sysconfdir}/cloud/cloud.cfg
%endif
%endif
%endif
%if 0%{?suse_version} && 0%{?suse_version} > 1110
mkdir -p %{buildroot}/%{_sysconfdir}/rsyslog.d
mkdir -p %{buildroot}/usr/lib/udev/rules.d/
cp -a %{SOURCE2} %{buildroot}/%{_sysconfdir}/rsyslog.d/21-cloudinit.conf
mv %{buildroot}/lib/udev/rules.d/66-azure-ephemeral.rules %{buildroot}/usr/lib/udev/rules.d/
%endif

# remove debian/ubuntu specific profile.d file (bnc#779553)
rm -f %{buildroot}%{_sysconfdir}/profile.d/Z99-cloud-locale-test.sh

# Remove non-SUSE templates
rm %{buildroot}/%{_sysconfdir}/cloud/templates/*.debian.*
rm %{buildroot}/%{_sysconfdir}/cloud/templates/*.redhat.*
rm %{buildroot}/%{_sysconfdir}/cloud/templates/*.ubuntu.*

# move sysvinit scripts into the "right" place
%if 0%{?suse_version} && 0%{?suse_version} <= 1210
mkdir -p %{buildroot}/%{_initddir}
mkdir -p %{buildroot}/%{_sbindir}
pushd "%{buildroot}%{_initddir}"
for iniF in *; do
    ln -s "%{_initddir}/${iniF}" "%{buildroot}/%{_sbindir}/rc${iniF}"
done
popd
%endif

# remove duplicate files
%if 0%{?suse_version}
%fdupes %{buildroot}%{python_sitelib}
%endif

%postun
%insserv_cleanup

%files
%defattr(-,root,root)
# do not mark as doc or we get conflicts with the doc package
%{docdir}/LICENSE
%{_bindir}/cloud-init
%{_bindir}/cloud-init-per
%dir %{_sysconfdir}/cloud
%config(noreplace) %{_sysconfdir}/cloud/cloud.cfg.d
%config(noreplace) %{_sysconfdir}/cloud/templates
%{_sysconfdir}/dhcp/dhclient-exit-hooks.d/hook-dhclient
%{_sysconfdir}/NetworkManager/dispatcher.d/hook-network-manager
%{python_sitelib}/cloudinit
%{python_sitelib}/cloud_init-%{version}-py%{py_ver}.egg-info
%{_prefix}/lib/cloud-init
%if 0%{?suse_version} && 0%{?suse_version} <= 1210
%{_sbindir}/rccloud-config
%{_sbindir}/rccloud-init
%{_sbindir}/rccloud-init-local
%{_sbindir}/rccloud-final
%attr(0755, root, root) %{_initddir}/cloud-config
%attr(0755, root, root) %{_initddir}/cloud-init
%attr(0755, root, root) %{_initddir}/cloud-init-local
%attr(0755, root, root) %{_initddir}/cloud-final
%else
%{systemd_prefix}/systemd/system-generators/cloud-init-generator
%{systemd_prefix}/systemd/system/cloud-config.service
%{systemd_prefix}/systemd/system/cloud-config.target
%{systemd_prefix}/systemd/system/cloud-init-local.service
%{systemd_prefix}/systemd/system/cloud-init.service
%{systemd_prefix}/systemd/system/cloud-init.target
%{systemd_prefix}/systemd/system/cloud-final.service
%endif
%if 0%{?suse_version} && 0%{?suse_version} > 1110
%dir %{_sysconfdir}/rsyslog.d
%{_sysconfdir}/rsyslog.d/21-cloudinit.conf
/usr/lib/udev/rules.d/66-azure-ephemeral.rules
# This if condition really distinquished between OBS and IBS.
# For SLE 12 builds in OBS owning the directories is not required, while
# SLE 12 builds in IBS require owning the directories
%else
/lib/udev/rules.d/66-azure-ephemeral.rules
%endif
%dir %attr(0755, root, root) %{_localstatedir}/lib/cloud
%dir %{docdir}
%dir /etc/NetworkManager
%dir /etc/NetworkManager/dispatcher.d
%dir /etc/dhcp
%dir /etc/dhcp/dhclient-exit-hooks.d

%files config-suse
%defattr(-,root,root)
%config(noreplace) %{_sysconfdir}/cloud/cloud.cfg

%files doc
%defattr(-,root,root)
%{docdir}/examples/*
%{docdir}/README
%{docdir}/*.txt
%{docdir}/*.rst
%dir %{docdir}/examples

%files test
%defattr(-,root,root)
%{python_sitelib}/tests

%changelog
* Thu Feb 16 2017 rjschwei@suse.com
- Do not set mount options for ephemeral drive, use the defaults
  that are built into the code (bsc#930524)
* Thu Feb 16 2017 rjschwei@suse.com
- Update fix-default-systemd-unit-dir.patch (bsc#1024709)
  + based on work by Thomas Abraham
- Add cloud-init-handle-not-implemented-query.patch (boo#1017832)
* Mon Jan 23 2017 kukuk@suse.de
- Require net-tools for network setup
* Sat Dec 17 2016 rjschwei@suse.com
- Configuration split (bsc#1016160)
* Tue Dec 13 2016 kukuk@suse.de
- fix syntax error in datasource LocalDisk (fix got somehow lost)
* Mon Dec 12 2016 dmueller@suse.com
- adjust license (as of 0.7.8 AGPL-3.0 was added)
* Mon Dec 12 2016 dmueller@suse.com
- fix unintentional edit in last change again
* Fri Dec  9 2016 jgleissner@suse.com
- Modify suseIntegratedHandler.patch (bsc#998103)
  + Store previous hostname so update_hostname module does not
    overwrite manually set hostnames
- cloud-init-python26.patch
  + Compatibility fixes with Python 2.6
* Thu Dec  8 2016 dmueller@suse.com
- fix the cloud.cfg split, cyclic non-versioned dependencies are
  bad. also fix changelog entries
* Thu Dec  1 2016 kukuk@suse.de
- add datasourceLocalDisk.patch:
  * Fix datasourceLocalDisk module in case directory exists but is
  empty.
* Wed Nov 30 2016 kukuk@suse.com
- Add Conflicts for otherproviders of cloud-init-config.
- Add require for python-six (used by several modules)
* Mon Nov 28 2016 kukuk@suse.com
- Add LocalDisk datasource datasourceLocalDisk.patch [FATE#321107]
* Wed Nov 23 2016 kukuk@suse.de
- Reworked zypp_add_repos.diff to behave similar to zypper ar
* Tue Nov 22 2016 kukuk@suse.de
- Move cloud.cfg into an own sub-package, so that we can have
  a product specific version. [FATE#322039]
* Sun Nov 13 2016 kukuk@suse.de
- Add zypp_add_repos.diff to support repos for zypper [FATE#322038]
* Tue Nov  1 2016 rjschwei@suse.com
- Modify suseIntegratedHandler.patch (bsc#1007529)
  + Fall back to the previous method of writing network information
    We have to work out upstream how to have distro specific renderer
    for sysconfig
* Mon Oct 31 2016 rjschwei@suse.com
- Add cloud-init-sysconfig-netpathfix.patch (bsc#1007529)
  + Fix the default path for network scripts
- Cosmetic changes to suseIntegratedHandler.patch
* Sat Oct 29 2016 rjschwei@suse.com
- Update cloud-init-no-dmidecode-on-ppc64.patch (bsc#1005616)
  + aarch64 does support dmidecode
* Sat Oct 29 2016 rjschwei@suse.com
- Update cloud-init-service.patch
  + Break another cycle this one in -final
* Fri Oct 28 2016 rjschwei@suse.com
- Update cloud-init-service.patch
  + Better match upstream intend Ubuntu networking.service is equivalent
    to SUSE wicked, thus we cannot translate networking to network, but need
    to translate it to wicked
* Fri Oct 28 2016 rjschwei@suse.com
- Update cloud-init-service.patch
  + We need the following order:
  - something brings networking fully up (in our case wicked)
  - cloud-init.service runs
  - network-online.target is reached
* Fri Oct 28 2016 rjschwei@suse.com
- Update cloud-init-service.patch
  + The network must be up an running in order to get ssh key injected
* Fri Oct 28 2016 rjschwei@suse.com
- Update cloud-init-service.patch
  + Had self reference and thus cloud-init.service was never executed
    which caused ssh key loading failure
* Fri Oct 28 2016 bwiedemann@suse.com
- Do not own /lib/udev to not conflict with udev rpm
* Thu Oct 27 2016 rjschwei@suse.com
- Forward port suseIntegratedHandler.patch
  + Implement new abstract interfaces
  + Some minor implementation fixes
* Wed Oct 26 2016 rjschwei@suse.com
- Appease the build service, differences between OBS and IBS,
  and own the directories
* Wed Oct 26 2016 rjschwei@suse.com
- Fix package, udev rules should be in /usr for distros after
  SLES 11
* Wed Oct 19 2016 dmueller@suse.com
- add cloud-init-digital-ocean-datasource-enable-by-default.patch,
  cloud-init-digital-ocean-datasource.patch: add DigitalOcean support
- run tests on build
* Tue Oct 11 2016 rjschwei@suse.com
- Add cloud-init-handle-no-carrier.patch (boo#1003977)
  - Handle the exception when attempting to detect if the network
    device is up when it is not
* Mon Oct 10 2016 rjschwei@suse.com
- Update cloud-init-service.patch (boo#999942)
  - Backport upstream commits 3705bb5964a and 6e45ffb21e96
* Thu Sep 15 2016 rjschwei@suse.com
- Decoding error (boo#998843)
  + Added cloud-init-fix-unicode-handling-binarydecode.patch
- Fix dependencies, depends on oauthlib instead of oauth
* Wed Sep 14 2016 rjschwei@suse.com
- Fix dataSourceOpenNebula.patch, missing closing paren (boo#998836)
* Wed Sep 14 2016 rjschwei@suse.com
- Fix typo in cloud-init-service.patch
* Tue Sep 13 2016 rjschwei@suse.com
- update to version 0.7.8 (bsc#998103)
  + added cloud-init-net-eni.patch based on work by eblock
  - Using config-drive instead of metadata failed because the network
    translation to Ubuntu-style did not return gateway information to
    opensuse.py
  + added cloud-init-service.patch based on work by eblock
  - The service file cloud-init.service referenced networking.service
    which on SUSE is network.service
  + remove no_logic_change.patch included in updated upstream source
  + forward port suseIntegratedHandler.patch
  + forward port setupSUSEsysVInit.diff
  + forward port cloud-init-no-dmidecode-on-ppc64.patch
  + foward port dataSourceOpenNebula.patch
  + forward port fix-default-systemd-unit-dir.patch
  + forward port cloud-init-finalbeforelogin.patch
  + forward port cloud-init-python2-sigpipe.patch
  + SmartOS: more improvements for network configuration
  + add ntp config module [Ryan Harper]
  + ChangeLog: update changelog for previous commit.
  + Add distro tags on config modules that should have it.
  + NoCloud: fix bug providing network-interfaces via meta-data. (LP: 1577982)
  + ConfigDrive: recognize 'tap' as a link type. (LP: #1610784)
  + Upgrade to a configobj package new enough to work
  + MAAS: add vendor-data support (LP: #1612313)
  + DigitalOcean: use the v1.json endpoint [Ben Howard]
  + Get Azure endpoint server from DHCP client [Brent Baude]
  + Apt: add new apt configuration format [Christian Ehrhardt]
  + distros: fix get_primary_arch method use of os.uname [Andrew Jorgensen]
  + Fix Gentoo net config generation [Matthew Thode]
  + Minor cleanups to atomic_helper and add unit tests.
  + azure dhclient-hook cleanups
  + network: fix get_interface_mac for bond slave, read_sys_net for ENOTDIR
  + Generate a dummy bond name for OpenStack (LP: #1605749)
  + add install option for openrc [Matthew Thode]
  + Add a module that can configure spacewalk.
  + python2.6: fix dict comprehension usage in _lsb_release.
  + apt-config: allow both old and new format to be present.
  [Christian Ehrhardt] (LP: #1616831)
  + bddeb: add --release flag to specify the release in changelog.
  + salt minion: update default pki directory for newer salt minion.
  (LP: #1609899)
  + Fix typo in default keys for phone_home [Roland Sommer] (LP: #1607810)
  + apt config conversion: treat empty string as not provided.  (LP: #1621180)
  + tests: cleanup tempdirs in apt_source tests
  + systemd: Better support package and upgrade. (LP: #1576692, #1621336)
  + remove obsolete .bzrignore
  + DataSourceOVF: fix user-data as base64 with python3 (LP: #1619394)
  + Allow link type of null in network_data.json [Jon Grimm] (LP: #1621968)
  from 0.7.7:
  + Digital Ocean: add datasource for Digital Ocean. [Neal Shrader]
  + expose uses_systemd as a distro function (fix rhel7)
  + fix broken 'output' config (LP: #1387340)
  + begin adding cloud config module docs to config modules (LP: #1383510)
  + retain trailing eol from template files (sources.list) when
  rendered with jinja (LP: #1355343)
  + Only use datafiles and initsys addon outside virtualenvs
  + Fix the digital ocean test case on python 2.6
  + Increase the usefulness, robustness, configurability of the chef module
  so that it is more useful, more documented and better for users
  + Fix how '=' signs are not handled that well in ssh_utils (LP: #1391303)
  + Be more tolerant of ssh keys passed into 'ssh_authorized_keys'; allowing
  for list, tuple, set, dict, string types and warning on other unexpected
  types
  + Update to use newer/better OMNIBUS_URL for chef module
  + GCE: Allow base64 encoded user-data (LP: #1404311) [Wayne Witzell III]
  + GCE: use short hostname rather than fqdn (LP: #1383794) [Ben Howard]
  + systemd: make init stage run before login prompts shown [Steve Langasek]
  + hostname: on first boot apply hostname to be same as is written for
  persistent hostname.  (LP: #1246485)
  + remove usage of dmidecode on linux in favor of /sys interface [Ben Howard]
  + python3 support [Barry Warsaw, Daniel Watkins, Josh Harlow] (LP: #1247132)
  + support managing gpt partitions in disk config [Daniel Watkins]
  + Azure: utilze gpt support for ephemeral formating [Daniel Watkins]
  + CloudStack: support fetching password from virtual router [Daniel Watkins]
  (LP: #1422388)
  + readurl, read_file_or_url returns bytes, user must convert as necessary
  + SmartOS: use v2 metadata service (LP: #1436417) [Daniel Watkins]
  + NoCloud: fix local datasource claiming found without explicit dsmode
  + Snappy: add support for installing snappy packages and configuring.
  + systemd: use network-online instead of network.target (LP: #1440180)
  [Steve Langasek]
  + Add functionality to fixate the uid of a newly added user.
  + Don't overwrite the hostname if the user has changed it after we set it.
  + GCE datasource does not handle instance ssh keys (LP: 1403617)
  + sysvinit: make cloud-init-local run before network (LP: #1275098)
  [Surojit Pathak]
  + Azure: do not re-set hostname if user has changed it (LP: #1375252)
  + Fix exception when running with no arguments on Python 3. [Daniel Watkins]
  + Centos: detect/expect use of systemd on centos 7. [Brian Rak]
  + Azure: remove dependency on walinux-agent [Daniel Watkins]
  + EC2: know about eu-central-1 availability-zone (LP: #1456684)
  + Azure: remove password from on-disk ovf-env.xml (LP: #1443311) [Ben Howard]
  + Doc: include information on user-data in OpenStack [Daniel Watkins]
  + Systemd: check for systemd using sd_booted symantics (LP: #1461201)
  [Lars Kellogg-Stedman]
  + Add an rh_subscription module to handle registration of Red Hat instances.
  [Brent Baude]
  + cc_apt_configure: fix importing keys under python3 (LP: #1463373)
  + cc_growpart: fix specification of 'devices' list (LP: #1465436)
  + CloudStack: fix password setting on cloudstack > 4.5.1 (LP: #1464253)
  + GCE: fix determination of availability zone (LP: #1470880)
  + ssh: generate ed25519 host keys (LP: #1461242)
  + distro mirrors: provide datasource to mirror selection code to support
  GCE regional mirrors. (LP: #1470890)
  + add udev rules that identify ephemeral device on Azure (LP: #1411582)
  + _read_dmi_syspath: fix bad log message causing unintended exception
  + rsyslog: add additional configuration mode (LP: #1478103)
  + status_wrapper in main: fix use of print_exc when handling exception
  + reporting: add reporting module for web hook or logging of events.
  + NoCloud: fix consumption of vendordata (LP: #1493453)
  + power_state_change: support 'condition' to disable or enable poweroff
  + ubuntu fan: support for config and installing of ubuntu fan (LP: #1504604)
  + Azure: support extracting SSH key values from ovf-env.xml (LP: #1506244)
  + AltCloud: fix call to udevadm settle (LP: #1507526)
  + Ubuntu templates: modify sources.list template to provide same sources
  as install from server or desktop ISO. (LP: #1177432)
  + cc_mounts: use 'nofail' if system uses systemd. (LP: #1514485)
  + Azure: get instance id from dmi instead of SharedConfig (LP: #1506187)
  + systemd/power_state: fix power_state to work even if cloud-final
  exited non-zero (LP: #1449318)
  + SmartOS: Add support for Joyent LX-Brand Zones (LP: #1540965)
  [Robert C Jennings]
  + systemd: support using systemd-detect-virt to detect container
  (LP: #1539016) [Martin Pitt]
  + docs: fix lock_passwd documentation [Robert C Jennings]
  + Azure: Handle escaped quotes in WALinuxAgentShim.find_endpoint.
  (LP: #1488891) [Dan Watkins]
  + lxd: add support for setting up lxd using 'lxd init' (LP: #1522879)
  + Add Image Customization Parser for VMware vSphere Hypervisor
  Support. [Sankar Tanguturi]
  + timezone: use a symlink rather than copy for /etc/localtime
  unless it is already a file (LP: #1543025).
  + Enable password changing via a hashed string [Alex Sirbu]
  + Added BigStep datasource [Alex Sirbu]
  + No longer run pollinate in seed_random (LP: #1554152)
  + groups: add defalt user to 'lxd' group.  Create groups listed
  for a user if they do not exist. (LP: #1539317)
  + dmi data: fix failure of reading dmi data for unset dmi values
  + doc: mention label for nocloud datasource must be 'cidata' [Peter Hurley]
  + ssh_pwauth: fix module to support 'unchanged' and match behavior
  described in documentation [Chris Cosby]
  + quickly check to see if the previous instance id is still valid to
  avoid dependency on network metadata service on every boot (LP: #1553815)
  + support network configuration in cloud-init --local with support
  device naming via systemd.link.
  + FreeBSD: add support for installing packages, setting password and
  timezone.  Change default user to 'freebsd'. [Ben Arblaster]
  + locale: list unsupported environment settings in warning (LP: #1558069)
  + disk_setup: correctly send --force to mkfs on block devices (LP: #1548772)
  + chef: fix chef install from gems (LP: #1553345)
  + systemd: do not specify After of obsolete syslog.target (LP: #1536964)
  + centos: Ensure that resolve conf object is written as a str (LP: #1479988)
  + chef: straighten out validation_cert and validation_key (LP: #1568940)
  + phone_home: allow usage of fqdn (LP: #1566824) [Ollie Armstrong]
  + cloudstack: Only use DHCPv4 lease files as a datasource (LP: #1576273)
  [Wido den Hollander]
  + Paths: fix instance path if datasource's id has a '/'. (LP: #1575938)
  [Robert Jennings]
  + Ec2: do not retry requests for user-data path on 404.
  + settings on the kernel command line (cc:) override all local settings
  rather than only those in /etc/cloud/cloud.cfg (LP: #1582323)
  + Improve merging documentation [Daniel Watkins]
  + apt sources: support inserting key/key-id only, custom sources.list,
  long gpg key fingerprints with spaces, and dictionary format (LP: #1574113)
  + SmartOS: datasource improvements and support for metadata service
  providing networking information.
  + Datasources: centrally handle 'dsmode' and no longer require datasources
  to "pass" if modules_init should be executed with network access.
  + ConfigDrive: improved support for networking information from
  a network_data.json or older interfaces formated network_config.
  + Change missing Cheetah log warning to debug [Andrew Jorgensen]
  + Remove trailing dot from GCE metadata URL (LP: #1581200) [Phil Roche]
  + support network rendering to sysconfig (for centos and RHEL)
  + write_files: if no permissions are given, just use default without warn.
  + user_data: fix error when user-data is not utf-8 decodable (LP: #1532072)
  + fix mcollective module with python3 (LP: #1597699) [Sergii Golovatiuk]
* Mon Jun  6 2016 joachim.gleissner@suse.com
- Add cloud-init-python2-sigpipe.patch (bsc#903449)
  + Restore SIGPIPE default handler when executing shell scripts
* Tue May  3 2016 rjschwei@suse.com
- Add cloud-init-finalbeforelogin.patch (bsc#978048)
  + Ordering issue, avoid login prompt before cloud-init is finished
* Tue Mar 15 2016 rjschwei@suse.com
- Update suseIntegratedHandler.patch (bsc#971275)
  + Properly handle the package_upgrade configuration option
* Tue Oct  6 2015 rjschwei@suse.com
- Add dependency on jinja2 (bsc#948995,bsc#948996)
* Mon Jun 29 2015 rjschwei@suse.com
- Add no_logic_change.patch to undo upstream logic changes introduced during
  style clean up
* Wed May 20 2015 rjschwei@suse.com
- Properly write the routes file for static networks (bnc#920190)
  + modify suseIntegratedHandler.patch
- Remove suseSetInitCmd.patch
  + is now integrated with suseIntegratedHandler.patch
* Mon Apr 27 2015 rjschwei@suse.com
- pmtools only exist on Intel architecture (bnc#928552)
* Mon Apr 13 2015 tbechtold@suse.com
- update to 0.7.6:
  - open 0.7.6
  - Enable vendordata on CloudSigma datasource (LP: #1303986)
  - Poll on /dev/ttyS1 in CloudSigma datasource only if dmidecode says
    we're running on cloudsigma (LP: #1316475) [Kiril Vladimiroff]
  - SmartOS test: do not require existance of /dev/ttyS1. [LP: #1316597]
  - doc: fix user-groups doc to reference plural ssh-authorized-keys
    (LP: #1327065) [Joern Heissler]
  - fix 'make test' in python 2.6
  - support jinja2 as a templating engine.  Drop the hard requirement on
    cheetah.  This helps in python3 effort. (LP: #1219223)
  - change install path for systemd files to /lib/systemd/system
    [Dimitri John Ledkov]
  - change trunk debian packaging to use pybuild and drop cdbs.
    [Dimitri John Ledkov]
  - SeLinuxGuard: remove invalid check that looked for stat.st_mode in os.lstat.
  - do not write comments in /etc/timezone (LP: #1341710)
  - ubuntu: provide 'ubuntu-init-switch' module to aid in systemd testing.
  - status/result json: remove 'end' entry which was always null
  - systemd: make cloud-init block ssh service startup to guarantee keys
    are generated. [Jordan Evans] (LP: #1333920)
  - default settings: fix typo resulting in OpenStack and GCE not working
    unless config explicitly provided (LP: #1329583) [Garrett Holmstrom])
  - fix rendering resolv.conf if no 'options' are provided (LP: #1328953)
  - docs: fix disk-setup to reference 'table_type' [Rail Aliiev] (LP: #1313114)
  - ssh_authkey_fingerprints: fix bug that prevented disabling the module.
    (LP: #1340903) [Patrick Lucas]
  - no longer use pylint as a checker, fix pep8 [Jay Faulkner].
  - Openstack: do not load some urls twice.
  - FreeBsd: fix initscripts and add working config file [Harm Weites]
  - Datasource: fix broken logic to provide hostname if datasource does not
    provide one
  - Improved and less verbose logging.
  - resizefs: first check that device is writable.
  - configdrive: fix reading of vendor data to be like metadata service reader.
    [Jay Faulkner]
  - resizefs: fix broken background resizing [Jay Faulkner] (LP: #1338614)
  - cc_grub_dpkg: fix EC2 hvm instances to avoid prompt on grub update.
    (LP: #1336855)
  - FreeBsd: support config drive datasource [Joseph bajin]
  - cc_mounts: support creating a swap file
- Refresh addopenSUSEBase.patch
- Refresh setupSUSEsysVInit.diff
- Removed cloudinit-datasources.patch. Applied upstream
- BuildRequires pkg-config. Needed to find correct systemd unit dir.
- Add fix-default-systemd-unit-dir.patch . Use better default for
  systemd system unit dir.
* Tue Feb 24 2015 rjschwei@suse.com
- Fix (bnc#919305 & bnc#918952)
  - Properly handle persistent network device names for OpenNebula
    + add dataSourceOpenNebula.patch
  - Properly set up network mode if interface config file
    + modified suseIntegratedHandler.patch
* Thu Feb  5 2015 tbechtold@suse.com
- Require e2fsprogs for filesystem resizing
* Tue Feb  3 2015 tbechtold@suse.com
- Remove Requires for python-yaml . There's already the right
  requirement for python-PyYAML
* Fri Nov 21 2014 reik.keutterling@nodefall.de
- fixed syntax error in dmidecode on ppc64 patch (bnc#914920)
* Tue Sep 16 2014 ms@suse.de
- users-groups module checks if the account is locked by
  calling 'passwd -l' which is ok but it should not raise
  if the account is already locked. This patch will cause
  lock_passwd to raise only if the account locking failed
  cloud-init-no-user-lock-if-already-locked.patch
* Sat Aug  9 2014 dvlaeev@suse.com
- Make package Arch dependent otherwise package is not installable
  on architectures where dmidecode is not available.
- Avoid to run dmidecode on PowerPC as well
  cloud-init-no-dmidecode-on-ppc64.patch
* Mon Jul 28 2014 rschweikert@suse.com
- declare rsyslog.d only for distros where it is created
  fixes build error on SLE 11
* Mon Jul 28 2014 rschweikert@suse.com
- add dmidecode (pmtools SLE 11) as dependency (bnc #888345)
* Tue Jul 22 2014 dmueller@suse.com
- fix typo in cloud.cfg (gowpart -> growpart)
- add cloudinit-datasources.patch: Fixes datasource list
* Mon Jul  7 2014 rschweikert@suse.com
- fix "typo" the rhel_util module is imported as rhutil, use the
  proper name when accessing (modifies suseIntegratedHandler.patch)
* Thu Jun 26 2014 rschweikert@suse.com
- add rsyslog filter rule to send cloud-init messages to
  /var/log/cloud-init.log
* Wed Jun 25 2014 rschweikert@suse.com
- initialize variable in method setting the instance hostname (BNC #884392)
  modifies: suseIntegratedHandler.patch
* Tue Jun 24 2014 rschweikert@suse.com
- add the python magic for package build on SLE 11
* Tue Jun 24 2014 rschweikert@suse.com
- add more dependencies to ensure commands used by the scripts are present
- add dynamicInitCmd.diff
  + support diffirent init systems across distribution versions for
    service restart
- add suseSetInitCmd.patch
  + properly setup the init command to support proper service restart
* Fri Jun 20 2014 rschweikert@suse.com
- integrate openSUSE and SLE handler code
  + remove openSUSEHandler.diff
  + add suseIntegratedHandler.patch
* Mon Apr 14 2014 rschweikert@suse.com
- update to version 0.7.5
  - open 0.7.5
  - Add a debug log message around import failures
  - add a 'debug' module for easily printing out some information about
    datasource and cloud-init [Shraddha Pandhe]
  - support running apt with 'eatmydata' via configuration token
    apt_get_wrapper (LP: #1236531).
  - convert paths provided in config-drive 'files' to string before writing
    (LP: #1260072).
  - Azure: minor changes in logging output. ensure filenames are strings (not
    unicode).
  - config/cloud.cfg.d/05_logging.cfg: provide a default 'output' setting, to
    redirect cloud-init stderr and stdout /var/log/cloud-init-output.log.
  - drop support for resizing partitions with parted entirely (LP: #1212492).
    This was broken as it was anyway.
  - add support for vendordata in SmartOS and NoCloud datasources.
  - drop dependency on boto for crawling ec2 metadata service.
  - add 'Requires' on sudo (for OpenNebula datasource) in rpm specs, and
    'Recommends' in the debian/control.in [Vlastimil Holer]
  - if mount_info reports /dev/root is a device path for /, then convert
    that to a device via help of kernel cmdline.
  - configdrive: consider partitions as possible datasources if they have
    theh correct filesystem label. [Paul Querna]
  - initial freebsd support [Harm Weites]
  - fix in is_ipv4 to accept IP addresses with a '0' in them.
  - Azure: fix issue when stale data in /var/lib/waagent (LP: #1269626)
  - skip config_modules that declare themselves only verified on a set of
    distros.  Add them to 'unverified_modules' list to run anyway.
  - Add CloudSigma datasource [Kiril Vladimiroff]
  - Add initial support for Gentoo and Arch distributions [Nate House]
  - Add GCE datasource [Vaidas Jablonskis]
  - Add native Openstack datasource which reads openstack metadata
    rather than relying on EC2 data in openstack metadata service.
  - SmartOS, AltCloud: disable running on arm systems due to bug
    (LP: #1243287, #1285686) [Oleg Strikov]
  - Allow running a command to seed random, default is 'pollinate -q'
    (LP: #1286316) [Dustin Kirkland]
  - Write status to /run/cloud-init/status.json for consumption by
    other programs (LP: #1284439)
  - Azure: if a reboot causes ephemeral storage to be re-provisioned
    Then we need to re-format it. (LP: #1292648)
  - OpenNebula: support base64 encoded user-data
    [Enol Fernandez, Peter Kotcauer]
- remove azure_1269626.diff, fix integrated in new version
- rename addopenSUSEBase.diff to addopenSUSEBase.patch, forward port
* Sat Mar 29 2014 rschweikert@suse.com
- fix implementation of the openSUSE handler, properly read the configuration
  from sysconfig
* Wed Mar 19 2014 rschweikert@suse.com
- do not package any none SUSE/openSUSE templates bnc#839707
- add patch openSUSEhostsTemplate.diff to add an openSUSE hosts template
* Wed Mar 19 2014 rschweikert@suse.com
- enable growing of root partition by default bnc#861473
* Tue Mar 18 2014 rschweikert@suse.com
- include the LICENSE
* Mon Mar 17 2014 rschweikert@suse.com
- include in SLE 12 (FATE #315990, #315991, and 316167)
- add patch azure_1269626.diff, fix for upstream bug 1269626
  + Azure instance do not boot properly after a capture operation
* Mon Mar 17 2014 rschweikert@suse.com
- add dependency on growpart to support root partition expansion
* Mon Jan 20 2014 dmueller@suse.com
- add python-jsonpatch, python-pyserial, python-PyYAML requires,
  otherwise it immediately traces on startup
* Sat Jan  4 2014 rschweikert@suse.com
- update to version 0.7.4
  + fix issue mounting 'ephemeral0' if ephemeral0 was an alias for a
    partitioned block device with target filesystem on ephemeral0.1.
    (LP: #1236594)
  + fix DataSourceAzure incompatibility with 2.6 (LP: #1232175)
  + fix power_state_change config module so that example works.  Improve
    its documentation and add reference to 'timeout'
  + support apt-add-archive with 'cloud-archive:' format.  (LP: #1244355)
  + Change SmartOS verb for availability zone (LP: #1249124)
  + documentation fix for boothooks to use 'cloud-init-per'
  + fix resizefs module by supporting kernels that do not have
    /proc/PID/mountinfo.  (LP: #1248625) [Tim Daly Jr.]
  + fix 'make rpm' by removing 0.6.4 entry from ChangeLog (LP: #1241834)
  + fix omnibus chef installer (LP: #1182265) [Chris Wing]
  + small fix for OVF datasource for iso transport on non-iso9660 filesystem
  + determine if upstart version is suitable for
    'initctl reload-configuration' (LP: #1124384).  If so, then invoke it.
    supports setting up instance-store disk with partition table and filesystem.
  + add Azure datasource.
  + add support for SuSE / SLES [Juerg Haefliger]
  + add a trailing carriage return to chpasswd input, which reportedly
    caused a problem on rhel5 if missing.
  + support individual MIME segments to be gzip compressed (LP: #1203203)
  + always finalize handlers even if processing failed (LP: #1203368)
  + support merging into cloud-config via jsonp. (LP: #1200476)
  + add datasource 'SmartOS' for Joyent Cloud.  Adds a dependency on serial.
  + add 'log_time' helper to util for timing how long things take
    which also reads from uptime. uptime is useful as clock may change during
    boot due to ntp.
  + prefer growpart resizer to 'parted resizepart' (LP: #1212492)
  + support random data seed from config drive or azure, and a module
    'seed_random' to read that and write it to /dev/urandom.
  + add OpenNebula Datasource [Vlastimil Holer]
  + add 'cc_disk_setup' config module for paritioning disks and creating
    filesystems.  Useful if attached disks are not formatted (LP: #1218506)
  + Fix usage of libselinux-python when selinux is disabled. [Garrett Holmstrom]
  + multi_log: only write to /dev/console if it exists [Garrett Holmstrom]
  + config/cloud.cfg: add 'sudo' to list groups for the default user
    (LP: #1228228)
  + documentation fix for use of 'mkpasswd' [Eric Nordlund]
  + respect /etc/growroot-disabled file (LP: #1234331)
- replace fixupSysVinit.patch with suseSysVInit.diff
  + sysV init files are now maintained by distribution, thus we need a patch
    that has the complete sysV init files rather then modifying existing files
- remove slesHandler.patch
  + SLES support is now integrated upstream
- add addopenSUSEBase.diff
  + remnants of the slesHandler.patch that add information about openSUSE
- add setupSUSEsysVInit.diff
  + integrate the SUSE sysV init scripts into setup.py
* Fri Aug  2 2013 rschweikert@suse.com
- remove the "nofail" option for the ephemeral storage
  + when using nofail an attempt is made to mount the filesystem twice
    once via udev and once through localfs, this results in a hanging
    system if fsck needs to run on the device
* Thu Jul 11 2013 speilicke@suse.com
- Install service files into /lib/systemd/system on 12.2, the UsrMove
  happened afterwards
* Wed Jul 10 2013 speilicke@suse.com
- Re-imported from IBS and some cleanup
- Package LICENSE
- Install service files to /usr/lib/systemd/system, not /etc/...
- Drop %%py_requires, there are several autorequires for SLES and openSUSE
- Drop $all facility Required-Start in sysvinit/cloud-final
* Wed Jun 26 2013 bwiedemann@suse.com
- require python-boto >= 2.7 because it fails with 2.5.2
* Wed Jun 26 2013 rschweikert@suse.com
- fix stray character in patch introduced by previous changes
* Wed Jun 26 2013 rschweikert@suse.com
- fix zypper command in slesHandler, use non-interactive mode
* Wed Jun 19 2013 rschweikert@suse.com
- fix duplicate entry in the config w.r.t. ssh key generation
- fix distro indicator setting, sles vs. opensuse
* Tue Jun 18 2013 rschweikert@suse.com
- Integrate the sysV init script changes from Jens
* Tue Jun 18 2013 rschweikert@suse.com
- integrate changes from HP
  + update the sles handler, do not modify the util code integrate
    routines directky into the sles handler
    ~ add patch slesHandler.patch
    ~ remove patch openSUSEHandler.diff
  + add python dependencies
    ~ python-argparse
    ~ python-configobj
    ~ python-oauth
  + update the cloud-init config file
* Sat Jun 15 2013 rschweikert@suse.com
- add the distro specific handler for openSUSE
  + patch openSUSEHandler.diff
- fix syntax in SLE handler
  + dict access uses [] not {}, duh
* Fri Jun 14 2013 rschweikert@suse.com
- add the distro specific handler for SLE
  + patch slesHandler.diff
* Wed Jun  5 2013 rschweikert@suse.com
- update to version 0.7.2, see Changelog in source for fixes
- use the upstream sysvinit and systemd files
- remove all previously created patches
  + drop-MAAS-datasource.diff
  + drop-python27-only-code.diff
  + drop-ubuntu-default-username.diff
  + relative-authorized-keys-file.diff
- create a doc and test package to reduce size of main package
- add patch (fixupSysVinit.patch) to fix the upstream sysvinit LSB headers
* Mon May  6 2013 jdsn@suse.de
- support relative path for authorized_keys file
  backport fix from upstream version 0.7.1 (bnc#818306)
* Wed Sep 19 2012 jdsn@suse.de
- fix usage of patches for openSUSE builds
* Thu Sep 13 2012 jdsn@suse.de
- drop ubuntu as default user name
- disable ssh ecdsa host key creation on SLE11
* Wed Sep 12 2012 jdsn@suse.de
- replace python 2.7 code with 2.5 compliant code
* Tue Sep 11 2012 jdsn@suse.de
- drop debian specific checks (bnc#779553)
* Mon Sep 10 2012 jdsn@suse.com
- Add python-xml Requires that was missing (bnc#779588).
* Fri Jul 20 2012 jdsn@suse.com
- fix init script, use killproc for stop operation (bnc#771803)
* Tue Jul  3 2012 cthiel@suse.com
- change license to SPDX format
* Wed Jun 27 2012 jdsn@suse.de
- rename to cloud-init
- drop MAAS support to avoid oauth dependency
